@@ -51,7 +51,7 @@ Plugin.create :display_requirements do
   end
 
   Message::Entity.addlinkrule(:hashtags, /(?:#|＃)[a-zA-Z0-9_]+/, :open_in_browser_hashtag){ |segment|
-    Gtk.openurl("https://twitter.com/search/realtime?q="+CGI.escape(segment[:url].match(/^(?:#|＃)?.+$/)[0]))
+    Gtk.openurl("https://twitter.com/search/realtime?q="+CGI.escape(segment[:url].match(/\A(?:#|＃)?.+\Z/)[0]))
   }
 
   # DR実績が解除されていたら差し戻す
@@ -79,15 +79,17 @@ class ::Gdk::MiraclePainter
     diff = (there - now).abs
     label = case diff
             when 0
-              "今"
+              Plugin[:display_requirements]._("今")
             when 1...60
-              "#{diff}秒#{there < now ? '前' : "後"}"
+              (there < now ? Plugin[:display_requirements]._("%{sec}秒前") : Plugin[:display_requirements]._("%{sec}秒後")) % {sec: diff}
             when 60...3600
-              "#{(diff/60).to_i}分#{there < now ? '前' : "後"}"
+              (there < now ? Plugin[:display_requirements]._('%{min}分前') : Plugin[:display_requirements]._('%{min}分後')) % {min: (diff/60).to_i}
             when 3600...86400
-              "#{(diff/3600).to_i}時間#{there < now ? '前' : "後"}"
+              (there < now ? Plugin[:display_requirements]._('%{hour}時間前') : Plugin[:display_requirements]._('%{hour}時間後')) % {hour: (diff/3600).to_i}
             else
-              message[:created].strftime('%Y/%m/%d')
+              # TRANSLATORS: Time#strftimeが食う形式。
+              # こんなん設定できたら良さそうだけどDRとかどうでもいいので適当にやってね
+              message[:created].strftime(Plugin[:display_requirements]._('%Y/%m/%d'))
             end
     Pango.escape(label)end
 
