@@ -25,7 +25,7 @@ class Service
 
     # 存在するServiceオブジェクトをSetで返す。
     # つまり、投稿権限のある「自分」のアカウントを全て返す。
-    alias services instances  
+    alias services instances
 
     # Service.instances.eachと同じ
     def each(*args, &proc)
@@ -103,7 +103,7 @@ class Service
       __destroy_e3de__("twitter#{service.user_obj.id}".to_sym)
       Plugin.call(:service_destroyed, service) end
     def remove_service(service)
-      destroy(service) end    
+      destroy(service) end
   end
 
   # プラグインには、必要なときにはこのインスタンスが渡るようになっているので、インスタンスを
@@ -261,7 +261,7 @@ class Service
   def user_initialize
     if defined? Service::SaveData.account_data(name.to_sym)[:user]
       @user_obj = User.new_ifnecessary(Service::SaveData.account_data(name.to_sym)[:user])
-      (twitter/:account/:verify_credentials).user.next(&method(:user_data_received)).trap(&method(:user_data_failed))
+      (twitter/:account/:verify_credentials).user.next(&method(:user_data_received)).trap(&method(:user_data_failed)).terminate
     else
       res = twitter.query!('account/verify_credentials', cache: true)
       if "200" == res.code
@@ -273,17 +273,20 @@ class Service
 
   def user_data_received(user)
     @user_obj = user
-    Service.account_modify name, {
+    Service::SaveData.account_modify name, {
       user: {
         id: @user_obj[:id],
         idname: @user_obj[:idname],
         name: @user_obj[:name],
         profile_image_url: @user_obj[:profile_image_url] } } end
 
-  def user_data_failed(e)
-    if e.is_a? MikuTwitter::Error
+  def user_data_failed(exception)
+    case exception
+    when MikuTwitter::Error
       if not UserConfig[:verify_credentials]
-        user_data_failed_crash!(e.httpresponse) end end end
+        user_data_failed_crash!(exception.httpresponse) end
+    else
+      raise exception end end
 
   def user_data_failed_crash!(res)
     if '400' == res.code
